@@ -41,7 +41,8 @@ def cmdparser():
     return parser
     
 
-
+if __name__ == "__main__":
+    run_from_cmd()
   
 
     
\ No newline at end of file
