@@ -2,7 +2,6 @@ import numpy as np
 import SimpleITK as sitk
 import sitk_tools
 
-
 def imsize_phys(image):
 
     
@@ -34,7 +33,8 @@ def round_geometry(image, decimals=3):
     
     return image
     
-    
+def zeros(*shape):
+    return sitk.GetImageFromArray(np.zeros(shape))    
     
     
 
